# OpenBB Derivatives Extension

This extension provides derivatives data for the OpenBB Platform.

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-derivatives
```

For development please check [Contribution Guidelines](https://github.com/OpenBB-finance/OpenBBTerminal/blob/develop/openbb_platform/CONTRIBUTING.md).

Documentation available [here](https://docs.openbb.co/sdk).
